@@ -393,7 +393,7 @@ class CfnApplication(
     @builtins.property
     @jsii.member(jsii_name="attrArn")
     def attr_arn(self) -> builtins.str:
-        '''The Arn for the application.
+        '''The Amazon resource name (ARN) that specifies the application across services.
 
         :cloudformationAttribute: Arn
         '''
@@ -402,7 +402,7 @@ class CfnApplication(
     @builtins.property
     @jsii.member(jsii_name="attrId")
     def attr_id(self) -> builtins.str:
-        '''The application Id in the respective resource.
+        '''The identifier of the application.
 
         :cloudformationAttribute: Id
         '''
@@ -598,7 +598,7 @@ class CfnAttributeGroup(
 
         :param scope: - scope in which this resource is defined.
         :param id: - scoped id of the resource.
-        :param attributes: A JSON string in the form of nested key-value pairs that represent the attributes in the group and describes an application and its components.
+        :param attributes: A nested object in a JSON or YAML template that supports arbitrary definitions. Represents the attributes in an attribute group that describes an application and its components.
         :param name: The name of the attribute group.
         :param description: The description of the attribute group that the user provides.
         :param tags: Key-value pairs you can use to associate with the attribute group.
@@ -646,7 +646,7 @@ class CfnAttributeGroup(
     @builtins.property
     @jsii.member(jsii_name="attrArn")
     def attr_arn(self) -> builtins.str:
-        '''The Arn for the attribute group.
+        '''The Amazon resource name (ARN) that specifies the attribute group across services.
 
         :cloudformationAttribute: Arn
         '''
@@ -655,7 +655,7 @@ class CfnAttributeGroup(
     @builtins.property
     @jsii.member(jsii_name="attrId")
     def attr_id(self) -> builtins.str:
-        '''The attribute group Id in the respective resource.
+        '''The globally unique attribute group identifier of the attribute group.
 
         :cloudformationAttribute: Id
         '''
@@ -678,7 +678,9 @@ class CfnAttributeGroup(
     @builtins.property
     @jsii.member(jsii_name="attributes")
     def attributes(self) -> typing.Any:
-        '''A JSON string in the form of nested key-value pairs that represent the attributes in the group and describes an application and its components.
+        '''A nested object in a JSON or YAML template that supports arbitrary definitions.
+
+        Represents the attributes in an attribute group that describes an application and its components.
 
         :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-servicecatalogappregistry-attributegroup.html#cfn-servicecatalogappregistry-attributegroup-attributes
         '''
@@ -732,7 +734,7 @@ class CfnAttributeGroupAssociation(
 ):
     '''A CloudFormation ``AWS::ServiceCatalogAppRegistry::AttributeGroupAssociation``.
 
-    The ``AWS::ServiceCatalogAppRegistry::AttributeGroupAssociation`` resource for ``ServiceCatalogAppRegistry`` .
+    Associates an attribute group with an application to augment the application's metadata with the group's attributes. This feature enables applications to be described with user-defined details that are machine-readable, such as third-party integrations.
 
     :cloudformationResource: AWS::ServiceCatalogAppRegistry::AttributeGroupAssociation
     :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-servicecatalogappregistry-attributegroupassociation.html
@@ -808,7 +810,8 @@ class CfnAttributeGroupAssociation(
     @builtins.property
     @jsii.member(jsii_name="attrApplicationArn")
     def attr_application_arn(self) -> builtins.str:
-        '''
+        '''The Amazon resource name (ARN) of the application that was augmented with attributes.
+
         :cloudformationAttribute: ApplicationArn
         '''
         return typing.cast(builtins.str, jsii.get(self, "attrApplicationArn"))
@@ -816,7 +819,8 @@ class CfnAttributeGroupAssociation(
     @builtins.property
     @jsii.member(jsii_name="attrAttributeGroupArn")
     def attr_attribute_group_arn(self) -> builtins.str:
-        '''
+        '''The Amazon resource name (ARN) of the attribute group that contains the application's new attributes.
+
         :cloudformationAttribute: AttributeGroupArn
         '''
         return typing.cast(builtins.str, jsii.get(self, "attrAttributeGroupArn"))
@@ -961,7 +965,7 @@ class CfnAttributeGroupProps:
     ) -> None:
         '''Properties for defining a ``CfnAttributeGroup``.
 
-        :param attributes: A JSON string in the form of nested key-value pairs that represent the attributes in the group and describes an application and its components.
+        :param attributes: A nested object in a JSON or YAML template that supports arbitrary definitions. Represents the attributes in an attribute group that describes an application and its components.
         :param name: The name of the attribute group.
         :param description: The description of the attribute group that the user provides.
         :param tags: Key-value pairs you can use to associate with the attribute group.
@@ -1005,7 +1009,9 @@ class CfnAttributeGroupProps:
 
     @builtins.property
     def attributes(self) -> typing.Any:
-        '''A JSON string in the form of nested key-value pairs that represent the attributes in the group and describes an application and its components.
+        '''A nested object in a JSON or YAML template that supports arbitrary definitions.
+
+        Represents the attributes in an attribute group that describes an application and its components.
 
         :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-servicecatalogappregistry-attributegroup.html#cfn-servicecatalogappregistry-attributegroup-attributes
         '''
@@ -1061,7 +1067,7 @@ class CfnResourceAssociation(
 ):
     '''A CloudFormation ``AWS::ServiceCatalogAppRegistry::ResourceAssociation``.
 
-    The ``AWS::ServiceCatalogAppRegistry::ResourceAssociation`` resource for ``ServiceCatalogAppRegistry`` .
+    Associates a resource with an application. Both the resource and the application can be specified either by ID or name.
 
     :cloudformationResource: AWS::ServiceCatalogAppRegistry::ResourceAssociation
     :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-servicecatalogappregistry-resourceassociation.html
@@ -1095,7 +1101,7 @@ class CfnResourceAssociation(
         :param id: - scoped id of the resource.
         :param application: The name or ID of the application.
         :param resource: The name or ID of the resource of which the application will be associated.
-        :param resource_type: The type of resource of which the application will be associated. Possible values: CFN_STACK.
+        :param resource_type: The type of resource of which the application will be associated.
         '''
         if __debug__:
             type_hints = typing.get_type_hints(_typecheckingstub__ac57fcddbbef8f965dbea4d61be6c43e13131294e8e36bd81e4838694c1c5d5a)
@@ -1140,7 +1146,8 @@ class CfnResourceAssociation(
     @builtins.property
     @jsii.member(jsii_name="attrApplicationArn")
     def attr_application_arn(self) -> builtins.str:
-        '''
+        '''The Amazon resource name (ARN) that specifies the application.
+
         :cloudformationAttribute: ApplicationArn
         '''
         return typing.cast(builtins.str, jsii.get(self, "attrApplicationArn"))
@@ -1157,7 +1164,8 @@ class CfnResourceAssociation(
     @builtins.property
     @jsii.member(jsii_name="attrResourceArn")
     def attr_resource_arn(self) -> builtins.str:
-        '''
+        '''The Amazon resource name (ARN) that specifies the resource.
+
         :cloudformationAttribute: ResourceArn
         '''
         return typing.cast(builtins.str, jsii.get(self, "attrResourceArn"))
@@ -1204,8 +1212,6 @@ class CfnResourceAssociation(
     def resource_type(self) -> builtins.str:
         '''The type of resource of which the application will be associated.
 
-        Possible values: CFN_STACK.
-
         :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-servicecatalogappregistry-resourceassociation.html#cfn-servicecatalogappregistry-resourceassociation-resourcetype
         '''
         return typing.cast(builtins.str, jsii.get(self, "resourceType"))
@@ -1239,7 +1245,7 @@ class CfnResourceAssociationProps:
 
         :param application: The name or ID of the application.
         :param resource: The name or ID of the resource of which the application will be associated.
-        :param resource_type: The type of resource of which the application will be associated. Possible values: CFN_STACK.
+        :param resource_type: The type of resource of which the application will be associated.
 
         :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-servicecatalogappregistry-resourceassociation.html
         :exampleMetadata: fixture=_generated
@@ -1291,8 +1297,6 @@ class CfnResourceAssociationProps:
     def resource_type(self) -> builtins.str:
         '''The type of resource of which the application will be associated.
 
-        Possible values: CFN_STACK.
-
         :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-servicecatalogappregistry-resourceassociation.html#cfn-servicecatalogappregistry-resourceassociation-resourcetype
         '''
         result = self._values.get("resource_type")
